@@ -1,7 +1,10 @@
 import os
 import psycopg2
 import csv
-from parser import BloombergParser, MarketWatchParser, RobinhoodParser, GoogleNewsParser, YahooFinancialParser, CNBCParser, ReutersParser, BenzingaParser
+from pprint import pprint
+
+from robinhood_scraper_nlp.model.article_data import NewsArticleData
+from robinhood_scraper_nlp.parser import BloombergParser, MarketWatchParser, RobinhoodParser, GoogleNewsParser, YahooFinancialParser, CNBCParser, ReutersParser, BenzingaParser
 from pyrh import Robinhood
 
 DEFAULT_TICKERS = ["FB", "AAPL", "AMZN", "NFLX", "GOOGL",
@@ -10,7 +13,6 @@ DEFAULT_TICKERS = ["FB", "AAPL", "AMZN", "NFLX", "GOOGL",
                    "LYFT", "SNAP", "AAPL", "CRM", "ACB",
                    "CRON", "APHA", "FIT", "GPRO", "SNAP", "TWTR"]
 
-
 class ScraperRunner:
 
     @classmethod
@@ -160,12 +162,13 @@ class ScraperRunner:
             data = None
             if source in switch_block:
                 p = switch_block[source](url, result)
-                data = p.parse()
+                data: NewsArticleData = p.parse()
                 if ticker not in data.tickers:
                     data.tickers.append(ticker)
             else:
                 print("No parser found for url:" + url)
             if data is not None:
+                pprint(vars(data))
                 fetched_results.append(data)
         return fetched_results
 
